==> firebase_performance-0.8.0%2B12.tar.gz: CHANGELOG.md <==
## 0.8.0+12

 - Update a dependency to the latest release.

## 0.8.0+11

 - Update a dependency to the latest release.

## 0.8.0+10

 - Update a dependency to the latest release.

## 0.8.0+9

 - Update a dependency to the latest release.

## 0.8.0+8

 - Update a dependency to the latest release.

## 0.8.0+7

 - **FIX**: update all Dart SDK version constraints to Dart >= 2.16.0 (#8184). ([df4a5bab](https://github.com/FirebaseExtended/flutterfire/commit/df4a5bab3c029399b4f257a5dd658d302efe3908))

## 0.8.0+6

 - **FIX**: Fix firebase_performance not recording response payload size on Android. (#8154). ([46d8bc0f](https://github.com/FirebaseExtended/flutterfire/commit/46d8bc0f205f24b1e160333ddb76200543f48c89))

## 0.8.0+5

 - Update a dependency to the latest release.

## 0.8.0+4

 - **FIX**: bump Android `compileSdkVersion` to 31 (#7726). ([a9562bac](https://github.com/FirebaseExtended/flutterfire/commit/a9562bac60ba927fb3664a47a7f7eaceb277dca6))

## 0.8.0+3

 - Update a dependency to the latest release.

## 0.8.0+2

 - Update a dependency to the latest release.

## 0.8.0+1

 - Update a dependency to the latest release.

## 0.8.0

> Note: This release has breaking changes.

The Firebase Performance plugin has been heavily reworked to bring it inline with the federated plugin setup along with adding new features,
documentation and updating unit and end-to-end tests.

- General
 - Collecting metric and attribute data was previously an asynchronous task. The API has been reworked to better reflect other Firebase APIs, whereby
   setting such data is now a synchronous task. Once a trace or HTTP metric stops, data will be sent to the Firebase services in a single operation.
   Because of this, breaking changes are introduced to support the new API.

- **`FirebasePerformance`**
  - **BREAKING**: `HttpMetric().putAttribute()` method is now synchronous.
  - **BREAKING**: `HttpMetric().removeAttribute()` method is now synchronous.
  - **BREAKING**: `HttpMetric().getAttribute()` method is now synchronous.
  - **BREAKING**: `HttpMetric().getAttributes()` method is now synchronous.
  - **BREAKING**: `Trace().putAttribute()` method is now synchronous.
  - **BREAKING**: `Trace().removeAttribute()` method is now synchronous.
  - **BREAKING**: `Trace().getAttribute()` method is now synchronous.
  - **BREAKING**: `Trace().getAttributes()` method is now synchronous.
  - **BREAKING**: `Trace().incrementMetric()` method is now synchronous.
  - **BREAKING**: `Trace().setMetric()` method is now synchronous.
  - **BREAKING**: `Trace().getMetric()` method is now synchronous.

## 0.7.1+5

 - Update a dependency to the latest release.

## 0.7.1+4

 - Update a dependency to the latest release.

## 0.7.1+3

 - Update a dependency to the latest release.

## 0.7.1+2

 - **REFACTOR**: remove deprecated Flutter Android v1 Embedding usages, including in example app (#7158).
 - **CHORE**: update Gradle versions used in Android example app (#7054).

## 0.7.1+1

 - **DOCS**: remove usage of private link address (#6986).
 - **CHORE**: update gradle version across packages (#7054).

## 0.7.1

 - **FIX**: fix the token verification. (#6912).
 - **FEAT**: add web support to the plugin (#6920).
 - **CHORE**: fix analyze issues (#6977).

## 0.7.0+9

 - **REFACTOR**: create interface plugin that federates the main plugin (#6851).

## 0.7.0+8

 - Update a dependency to the latest release.

## 0.7.0+7

 - **REFACTOR**: add all perf API usage to the firebase_performance example app.
 - **REFACTOR**: move plugin to a subdirectory.
 - **CHORE**: update v2 embedding support (#6506).

## 0.7.0+6

 - **REFACTOR**: add all perf API usage to the firebase_performance example app.
 - **REFACTOR**: move plugin to a subdirectory.

## 0.7.0+5

 - Update a dependency to the latest release.

## 0.7.0+4

 - Update a dependency to the latest release.

## 0.7.0+3

 - Update a dependency to the latest release.

## 0.7.0+2

 - Update a dependency to the latest release.

## 0.7.0+1

 - **FIX**: allow null values for `requestPayloadSize` and `responsePayloadSize` (#1711).

## 0.7.0

> Note: This release has breaking changes.

 - **BREAKING** **FEAT**: Migrate firebase_performance to sound null safety (#5540).

## 0.6.0+2

 - Update a dependency to the latest release.

## 0.6.0+1

 - **DOCS**: remove incorrect ARCHS in ios examples (#5450).
 - **CHORE**: bump min Dart SDK constraint to 2.12.0 (#5430).
 - **CHORE**: publish packages (#5429).
 - **CHORE**: merge all analysis_options.yaml into one (#5329).
 - **CHORE**: enable lints in firebase_performance (#5253).
 - **CHORE**: publish packages.

## 0.6.0

 - This version is not null-safe but has been created to allow compatibility with other null-safe FlutterFire packages such as `firebase_core`.

## 0.5.0

 - **BREAKING** **FEAT**: forward port to firebase-ios-sdk v7.3.0.
   - Due to this SDK upgrade, iOS 10 is now the minimum supported version by FlutterFire. Please update your build target version.

## 0.4.3

 - **FEAT**: bump android `com.android.tools.build` & `'com.google.gms:google-services` versions (#4269).
 - **CHORE**: publish packages.
 - **CHORE**: bump gradle wrapper to 5.6.4 (#4158).

## 0.4.2

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: bump `compileSdkVersion` to 29 in preparation for upcoming Play Store requirement.
 - **CHORE**: publish packages.
 - **CHORE**: publish packages.

## 0.4.1

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: update Firebase iOS SDK version to 6.33.0 (from 6.26.0).
 - **CHORE**: bump perf example min android sdk for multidex purposes.

## 0.4.0+2

 - Update a dependency to the latest release.

## 0.4.0+1

 - **FIX**: local dependencies in example apps (#3319).
 - **CHORE**: intellij cleanup (#3326).

## 0.4.0

* Depend on `firebase_core`.
* Firebase iOS SDK versions are now locked to use the same version defined in
  `firebase_core`.
* Firebase Android SDK versions are now using the Firebase Bill of Materials (BoM)
  to specify individual SDK versions. BoM version is also sourced from
  `firebase_core`.
* Allow iOS to be imported as a module.

## 0.3.2

* Update lower bound of dart dependency to 2.0.0.

## 0.3.1+8

* Fix for missing UserAgent.h compilation failures.

## 0.3.1+7

* Replace deprecated `getFlutterEngine` call on Android.

## 0.3.1+6

* Make the pedantic dev_dependency explicit.

## 0.3.1+5

* Remove the deprecated `author:` field from pubspec.yaml
* Migrate the plugin to the pubspec platforms manifest.
* Bump the minimum Flutter version to 1.10.0.

## 0.3.1+4

* Skip flaky driver tests.

## 0.3.1+3

* Fixed analyzer warnings about unused fields.

## 0.3.1+2

* Updated README instructions for contributing for consistency with other Flutterfire plugins.

## 0.3.1+1

* Remove AndroidX warning.

## 0.3.1

* Support v2 embedding. This will remain compatible with the original embedding and won't require
app migration.

## 0.3.0+5

* Update documentation to reflect new repository location.
* Update unit tests to call `TestWidgetsFlutterBinding.ensureInitialized`.

## 0.3.0+4

* Update google-services Android gradle plugin to 4.3.0 in documentation and examples.

## 0.3.0+3

* Fix bug that caused `invokeMethod` to fail with Dart code obfuscation

## 0.3.0+2

* Fix bug preventing this plugin from working with hot restart.

## 0.3.0+1

* Automatically use version from pubspec.yaml when reporting usage to Firebase.

## 0.3.0

* **Breaking Change** Removed `Trace.incrementCounter`. Please use `Trace.incrementMetric`.
* Assertion errors are no longer thrown for incorrect input for `Trace`s and `HttpMetric`s.
* You can now get entire list of attributes from `Trace` and `HttpMetric` with `getAttributes()`.
* Added access to `Trace` value `name`.
* Added access to `HttpMetric` values `url` and `HttpMethod`.

## 0.2.0

* Update Android dependencies to latest.

## 0.1.1

* Deprecate `Trace.incrementCounter` and add `Trace.incrementMetric`.
* Additional integration testing.

## 0.1.0+4

* Remove deprecated methods for iOS.
* Fix bug where `Trace` attributes were not set correctly.

## 0.1.0+3

* Log messages about automatic configuration of the default app are now less confusing.

## 0.1.0+2

* Fixed bug where `Traces` and `HttpMetrics` weren't being passed to Firebase on iOS.

## 0.1.0+1

* Log a more detailed warning at build time about the previous AndroidX
  migration.

## 0.1.0

* **Breaking change**. Migrate from the deprecated original Android Support
  Library to AndroidX. This shouldn't result in any functional changes, but it
  requires any Android apps using this plugin to [also
  migrate](https://developer.android.com/jetpack/androidx/migrate) if they're
  using the original support library.

## 0.0.8+1

* Bump Android dependencies to latest.

## 0.0.8

* Set http version to be compatible with flutter_test.

## 0.0.7

* Added missing http package dependency.

## 0.0.6

* Bump Android and Firebase dependency versions.

## 0.0.5

Added comments explaining the time it takes to see performance results.

## 0.0.4

* Formatted code, updated comments, and removed unnecessary files.

## 0.0.3

* Updated Gradle tooling to match Android Studio 3.1.2.

## 0.0.2

* Added HttpMetric for monitoring for specific network requests.

## 0.0.1

* Initial Release.

==> firebase_performance-0.9.3%2B12.tar.gz: CHANGELOG.md <==
## 0.9.3+12

 - Update a dependency to the latest release.

## 0.9.3+11

 - Update a dependency to the latest release.

## 0.9.3+10

 - Update a dependency to the latest release.

## 0.9.3+9

 - **DOCS**: change old documentation links of packages in README files ([#12136](https://github.com/firebase/flutterfire/issues/12136)). ([24b9ac7e](https://github.com/firebase/flutterfire/commit/24b9ac7ec29fc9ca466c0941c2cff26d75b8568d))

## 0.9.3+8

 - Update a dependency to the latest release.

## 0.9.3+7

 - Update a dependency to the latest release.

## 0.9.3+6

 - Update a dependency to the latest release.

## 0.9.3+5

 - Update a dependency to the latest release.

## 0.9.3+4

 - Update a dependency to the latest release.

## 0.9.3+3

 - Update a dependency to the latest release.

## 0.9.3+2

 - Update a dependency to the latest release.

## 0.9.3+1

 - Update a dependency to the latest release.

## 0.9.3

 - **FEAT**: Full support of AGP 8 ([#11699](https://github.com/firebase/flutterfire/issues/11699)). ([bdb5b270](https://github.com/firebase/flutterfire/commit/bdb5b27084d225809883bdaa6aa5954650551927))

## 0.9.2+7

 - Update a dependency to the latest release.

## 0.9.2+6

 - Update a dependency to the latest release.

## 0.9.2+5

 - Update a dependency to the latest release.

## 0.9.2+4

 - Update a dependency to the latest release.

## 0.9.2+3

 - Update a dependency to the latest release.

## 0.9.2+2

 - Update a dependency to the latest release.

## 0.9.2+1

 - Update a dependency to the latest release.

## 0.9.2

 - **FEAT**: update dependency constraints to `sdk: '>=2.18.0 <4.0.0'` `flutter: '>=3.3.0'` ([#10946](https://github.com/firebase/flutterfire/issues/10946)). ([2772d10f](https://github.com/firebase/flutterfire/commit/2772d10fe510dcc28ec2d37a26b266c935699fa6))

## 0.9.1+2

 - **FIX**: add support for AGP 8.0 ([#10901](https://github.com/firebase/flutterfire/issues/10901)). ([a3b96735](https://github.com/firebase/flutterfire/commit/a3b967354294c295a9be8d699a6adb7f4b1dba7f))

## 0.9.1+1

 - Update a dependency to the latest release.

## 0.9.1

 - **FEAT**: bump dart sdk constraint to 2.18 ([#10618](https://github.com/firebase/flutterfire/issues/10618)). ([f80948a2](https://github.com/firebase/flutterfire/commit/f80948a28b62eead358bdb900d5a0dfb97cebb33))

## 0.9.0+16

 - Update a dependency to the latest release.

## 0.9.0+15

 - **FIX**(performance,android): fix NullPointerException errors and remove suppressed warnings ([#10560](https://github.com/firebase/flutterfire/issues/10560)). ([a54d33df](https://github.com/firebase/flutterfire/commit/a54d33df6fdc4ccb3ef0b9e955e502b750aa592b))

## 0.9.0+14

 - Update a dependency to the latest release.

## 0.9.0+13

 - Update a dependency to the latest release.

## 0.9.0+12

 - Update a dependency to the latest release.

## 0.9.0+11

 - **REFACTOR**: replace deprecated API: `Tasks.call()` ([#10361](https://github.com/firebase/flutterfire/issues/10361)). ([22407847](https://github.com/firebase/flutterfire/commit/2240784774d6673319fdb32a90c52beb015d3714))
 - **FIX**: fix a crash that could occur with httpMetricStart when disabling collection ([#10392](https://github.com/firebase/flutterfire/issues/10392)). ([db67962b](https://github.com/firebase/flutterfire/commit/db67962b50269de7ebacc496e163fb8bb6608a12))

## 0.9.0+10

 - **FIX**: fix a crash that would occur when creating a trace with performance collection disabled ([#10243](https://github.com/firebase/flutterfire/issues/10243)). ([0a15ecbe](https://github.com/firebase/flutterfire/commit/0a15ecbe31a5730a6f8be2218c756a5d167e5bbd))

## 0.9.0+9

 - **REFACTOR**: refactor underlying implementation for the "handler system" so the handlers are generated on native side ([#9334](https://github.com/firebase/flutterfire/issues/9334)). ([08a4be6c](https://github.com/firebase/flutterfire/commit/08a4be6c0e86a3288bb6fcafd301f1519b7915ba))

## 0.9.0+8

 - Update a dependency to the latest release.

## 0.9.0+7

 - Update a dependency to the latest release.

## 0.9.0+6

 - Update a dependency to the latest release.

## 0.9.0+5

 - Update a dependency to the latest release.

## 0.9.0+4

 - Update a dependency to the latest release.

## 0.9.0+3

 - **REFACTOR**: add `verify` to `QueryPlatform` and change internal `verifyToken` API to `verify` ([#9711](https://github.com/firebase/flutterfire/issues/9711)). ([c99a842f](https://github.com/firebase/flutterfire/commit/c99a842f3e3f5f10246e73f51530cc58c42b49a3))

## 0.9.0+2

 - Update a dependency to the latest release.

## 0.9.0+1

 - Update a dependency to the latest release.

## 0.9.0

> Note: This release has breaking changes.

 - **BREAKING** **FEAT**: Firebase iOS SDK version: `10.0.0` ([#9708](https://github.com/firebase/flutterfire/issues/9708)). ([9627c56a](https://github.com/firebase/flutterfire/commit/9627c56a37d657d0250b6f6b87d0fec1c31d4ba3))

## 0.8.3+3

 - Update a dependency to the latest release.

## 0.8.3+2

 - Update a dependency to the latest release.

## 0.8.3+1

 - Update a dependency to the latest release.

## 0.8.3

 - **FEAT**: Bump Firebase iOS SDK to 9.5.0 ([#9492](https://github.com/firebase/flutterfire/issues/9492)). ([d246ba2a](https://github.com/firebase/flutterfire/commit/d246ba2aeec3da0bf5e2b4171ea2d1ec67618226))

## 0.8.2+4

 - Update a dependency to the latest release.

## 0.8.2+3

 - Update a dependency to the latest release.

## 0.8.2+2

 - Update a dependency to the latest release.

## 0.8.2+1

 - Update a dependency to the latest release.

## 0.8.2

 - **FEAT**: upgrade to support v9.8.1 Firebase JS SDK ([#8235](https://github.com/firebase/flutterfire/issues/8235)). ([4b417af5](https://github.com/firebase/flutterfire/commit/4b417af574bb8a32ca8e4b3ab2ff253a22be9903))

## 0.8.1+1

 - **FIX**: bump `firebase_core_platform_interface` version to fix previous release. ([bea70ea5](https://github.com/firebase/flutterfire/commit/bea70ea5cbbb62cbfd2a7a74ae3a07cb12b3ee5a))

## 0.8.1

 - **FEAT**: Bump Firebase iOS SDK to `9.2.0` (#8594). ([79610162](https://github.com/firebase/flutterfire/commit/79610162460b8877f3bc727464a7065106f08079))

## 0.8.0+14

 - **REFACTOR**: use `firebase.google.com` link for `homepage` in `pubspec.yaml` (#8737). ([5d5d4d21](https://github.com/firebase/flutterfire/commit/5d5d4d213233158971d7cb896a250d050e95e1a6))
 - **REFACTOR**: use "firebase" instead of "FirebaseExtended" as organisation in all links for this repository (#8791). ([d90b8357](https://github.com/firebase/flutterfire/commit/d90b8357db01d65e753021358668f0b129713e6b))
 - **DOCS**: point to "firebase.google" domain for hyperlinks in the usage section of `README.md` files (for the missing packages) (#8818). ([5bda8c92](https://github.com/firebase/flutterfire/commit/5bda8c92be1651a941d1285d36e885ee0b967b11))

## 0.8.0+13

 - Update a dependency to the latest release.

## 0.8.0+12

 - Update a dependency to the latest release.

## 0.8.0+11

 - Update a dependency to the latest release.

## 0.8.0+10

 - Update a dependency to the latest release.

## 0.8.0+9

 - Update a dependency to the latest release.

## 0.8.0+8

 - Update a dependency to the latest release.

## 0.8.0+7

 - **FIX**: update all Dart SDK version constraints to Dart >= 2.16.0 (#8184). ([df4a5bab](https://github.com/firebase/flutterfire/commit/df4a5bab3c029399b4f257a5dd658d302efe3908))

## 0.8.0+6

 - **FIX**: Fix firebase_performance not recording response payload size on Android. (#8154). ([46d8bc0f](https://github.com/firebase/flutterfire/commit/46d8bc0f205f24b1e160333ddb76200543f48c89))

## 0.8.0+5

 - Update a dependency to the latest release.

## 0.8.0+4

 - **FIX**: bump Android `compileSdkVersion` to 31 (#7726). ([a9562bac](https://github.com/firebase/flutterfire/commit/a9562bac60ba927fb3664a47a7f7eaceb277dca6))

## 0.8.0+3

 - Update a dependency to the latest release.

## 0.8.0+2

 - Update a dependency to the latest release.

## 0.8.0+1

 - Update a dependency to the latest release.

## 0.8.0

> Note: This release has breaking changes.

The Firebase Performance plugin has been heavily reworked to bring it inline with the federated plugin setup along with adding new features,
documentation and updating unit and end-to-end tests.

- General
 - Collecting metric and attribute data was previously an asynchronous task. The API has been reworked to better reflect other Firebase APIs, whereby
   setting such data is now a synchronous task. Once a trace or HTTP metric stops, data will be sent to the Firebase services in a single operation.
   Because of this, breaking changes are introduced to support the new API.

- **`FirebasePerformance`**
  - **BREAKING**: `HttpMetric().putAttribute()` method is now synchronous.
  - **BREAKING**: `HttpMetric().removeAttribute()` method is now synchronous.
  - **BREAKING**: `HttpMetric().getAttribute()` method is now synchronous.
  - **BREAKING**: `HttpMetric().getAttributes()` method is now synchronous.
  - **BREAKING**: `Trace().putAttribute()` method is now synchronous.
  - **BREAKING**: `Trace().removeAttribute()` method is now synchronous.
  - **BREAKING**: `Trace().getAttribute()` method is now synchronous.
  - **BREAKING**: `Trace().getAttributes()` method is now synchronous.
  - **BREAKING**: `Trace().incrementMetric()` method is now synchronous.
  - **BREAKING**: `Trace().setMetric()` method is now synchronous.
  - **BREAKING**: `Trace().getMetric()` method is now synchronous.

## 0.7.1+5

 - Update a dependency to the latest release.

## 0.7.1+4

 - Update a dependency to the latest release.

## 0.7.1+3

 - Update a dependency to the latest release.

## 0.7.1+2

 - **REFACTOR**: remove deprecated Flutter Android v1 Embedding usages, including in example app (#7158).
 - **CHORE**: update Gradle versions used in Android example app (#7054).

## 0.7.1+1

 - **DOCS**: remove usage of private link address (#6986).
 - **CHORE**: update gradle version across packages (#7054).

## 0.7.1

 - **FIX**: fix the token verification. (#6912).
 - **FEAT**: add web support to the plugin (#6920).
 - **CHORE**: fix analyze issues (#6977).

## 0.7.0+9

 - **REFACTOR**: create interface plugin that federates the main plugin (#6851).

## 0.7.0+8

 - Update a dependency to the latest release.

## 0.7.0+7

 - **REFACTOR**: add all perf API usage to the firebase_performance example app.
 - **REFACTOR**: move plugin to a subdirectory.
 - **CHORE**: update v2 embedding support (#6506).

## 0.7.0+6

 - **REFACTOR**: add all perf API usage to the firebase_performance example app.
 - **REFACTOR**: move plugin to a subdirectory.

## 0.7.0+5

 - Update a dependency to the latest release.

## 0.7.0+4

 - Update a dependency to the latest release.

## 0.7.0+3

 - Update a dependency to the latest release.

## 0.7.0+2

 - Update a dependency to the latest release.

## 0.7.0+1

 - **FIX**: allow null values for `requestPayloadSize` and `responsePayloadSize` (#1711).

## 0.7.0

> Note: This release has breaking changes.

 - **BREAKING** **FEAT**: Migrate firebase_performance to sound null safety (#5540).

## 0.6.0+2

 - Update a dependency to the latest release.

## 0.6.0+1

 - **DOCS**: remove incorrect ARCHS in ios examples (#5450).
 - **CHORE**: bump min Dart SDK constraint to 2.12.0 (#5430).
 - **CHORE**: publish packages (#5429).
 - **CHORE**: merge all analysis_options.yaml into one (#5329).
 - **CHORE**: enable lints in firebase_performance (#5253).
 - **CHORE**: publish packages.

## 0.6.0

 - This version is not null-safe but has been created to allow compatibility with other null-safe FlutterFire packages such as `firebase_core`.

## 0.5.0

 - **BREAKING** **FEAT**: forward port to firebase-ios-sdk v7.3.0.
   - Due to this SDK upgrade, iOS 10 is now the minimum supported version by FlutterFire. Please update your build target version.

## 0.4.3

 - **FEAT**: bump android `com.android.tools.build` & `'com.google.gms:google-services` versions (#4269).
 - **CHORE**: publish packages.
 - **CHORE**: bump gradle wrapper to 5.6.4 (#4158).

## 0.4.2

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: bump `compileSdkVersion` to 29 in preparation for upcoming Play Store requirement.
 - **CHORE**: publish packages.
 - **CHORE**: publish packages.

## 0.4.1

 - **FEAT**: bump compileSdkVersion to 29 (#3975).
 - **FEAT**: update Firebase iOS SDK version to 6.33.0 (from 6.26.0).
 - **CHORE**: bump perf example min android sdk for multidex purposes.

## 0.4.0+2

 - Update a dependency to the latest release.

## 0.4.0+1

 - **FIX**: local dependencies in example apps (#3319).
 - **CHORE**: intellij cleanup (#3326).

## 0.4.0

* Depend on `firebase_core`.
* Firebase iOS SDK versions are now locked to use the same version defined in
  `firebase_core`.
* Firebase Android SDK versions are now using the Firebase Bill of Materials (BoM)
  to specify individual SDK versions. BoM version is also sourced from
  `firebase_core`.
* Allow iOS to be imported as a module.

## 0.3.2

* Update lower bound of dart dependency to 2.0.0.

## 0.3.1+8

* Fix for missing UserAgent.h compilation failures.

## 0.3.1+7

* Replace deprecated `getFlutterEngine` call on Android.

## 0.3.1+6

* Make the pedantic dev_dependency explicit.

## 0.3.1+5

* Remove the deprecated `author:` field from pubspec.yaml
* Migrate the plugin to the pubspec platforms manifest.
* Bump the minimum Flutter version to 1.10.0.

## 0.3.1+4

* Skip flaky driver tests.

## 0.3.1+3

* Fixed analyzer warnings about unused fields.

## 0.3.1+2

* Updated README instructions for contributing for consistency with other Flutterfire plugins.

## 0.3.1+1

* Remove AndroidX warning.

## 0.3.1

* Support v2 embedding. This will remain compatible with the original embedding and won't require
app migration.

## 0.3.0+5

* Update documentation to reflect new repository location.
* Update unit tests to call `TestWidgetsFlutterBinding.ensureInitialized`.

## 0.3.0+4

* Update google-services Android gradle plugin to 4.3.0 in documentation and examples.

## 0.3.0+3

* Fix bug that caused `invokeMethod` to fail with Dart code obfuscation

## 0.3.0+2

* Fix bug preventing this plugin from working with hot restart.

## 0.3.0+1

* Automatically use version from pubspec.yaml when reporting usage to Firebase.

## 0.3.0

* **Breaking Change** Removed `Trace.incrementCounter`. Please use `Trace.incrementMetric`.
* Assertion errors are no longer thrown for incorrect input for `Trace`s and `HttpMetric`s.
* You can now get entire list of attributes from `Trace` and `HttpMetric` with `getAttributes()`.
* Added access to `Trace` value `name`.
* Added access to `HttpMetric` values `url` and `HttpMethod`.

## 0.2.0

* Update Android dependencies to latest.

## 0.1.1

* Deprecate `Trace.incrementCounter` and add `Trace.incrementMetric`.
* Additional integration testing.

## 0.1.0+4

* Remove deprecated methods for iOS.
* Fix bug where `Trace` attributes were not set correctly.

## 0.1.0+3

* Log messages about automatic configuration of the default app are now less confusing.

## 0.1.0+2

* Fixed bug where `Traces` and `HttpMetrics` weren't being passed to Firebase on iOS.

## 0.1.0+1

* Log a more detailed warning at build time about the previous AndroidX
  migration.

## 0.1.0

* **Breaking change**. Migrate from the deprecated original Android Support
  Library to AndroidX. This shouldn't result in any functional changes, but it
  requires any Android apps using this plugin to [also
  migrate](https://developer.android.com/jetpack/androidx/migrate) if they're
  using the original support library.

## 0.0.8+1

* Bump Android dependencies to latest.

## 0.0.8

* Set http version to be compatible with flutter_test.

## 0.0.7

* Added missing http package dependency.

## 0.0.6

* Bump Android and Firebase dependency versions.

## 0.0.5

Added comments explaining the time it takes to see performance results.

## 0.0.4

* Formatted code, updated comments, and removed unnecessary files.

## 0.0.3

* Updated Gradle tooling to match Android Studio 3.1.2.

## 0.0.2

* Added HttpMetric for monitoring for specific network requests.

## 0.0.1

* Initial Release.
